# openapi-client
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2.0
- Package version: 1.0.0
- Generator version: 7.9.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import openapi_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import openapi_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import openapi_client
from openapi_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://jira.devops.jlr-apps.com/rest/raven
# See configuration.py for a list of all supported configuration parameters.
configuration = openapi_client.Configuration(
    host = "https://jira.devops.jlr-apps.com/rest/raven"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: BasicAuth
configuration = openapi_client.Configuration(
    username = os.environ["USERNAME"],
    password = os.environ["PASSWORD"]
)

# Configure Bearer authorization: bearerAuth
configuration = openapi_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with openapi_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = openapi_client.DatasetApi(api_client)
    test_issue_id = 'test_issue_id_example' # str | The id of the test issue (optional)
    test_issue_key = 'test_issue_key_example' # str | The key of the test issue (optional)
    test_version = 'test_version_example' # str | A test version (optional)
    context_issue_id = 'context_issue_id_example' # str | The id of the context issue (Test Plan or Test Execution) (optional)
    context_issue_key = 'context_issue_key_example' # str | The key of the context issue (Test Plan or Test Execution) (optional)
    resolved = 'resolved_example' # str | A flag indicating of the dataset must be resolved or not for a given level (true by default) (optional)

    try:
        api_response = api_instance.call_10_api_dataset_export_get(test_issue_id=test_issue_id, test_issue_key=test_issue_key, test_version=test_version, context_issue_id=context_issue_id, context_issue_key=context_issue_key, resolved=resolved)
        print("The response of DatasetApi->call_10_api_dataset_export_get:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling DatasetApi->call_10_api_dataset_export_get: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://jira.devops.jlr-apps.com/rest/raven*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DatasetApi* | [**call_10_api_dataset_export_get**](docs/DatasetApi.md#call_10_api_dataset_export_get) | **GET** /1.0/api/dataset/export | 
*DatasetApi* | [**call_10_api_dataset_import_post**](docs/DatasetApi.md#call_10_api_dataset_import_post) | **POST** /1.0/api/dataset/import | 
*ExternalAppsApi* | [**call_10_api_xraylicense_get**](docs/ExternalAppsApi.md#call_10_api_xraylicense_get) | **GET** /1.0/api/xraylicense | 
*ImportApi* | [**post_import_execution**](docs/ImportApi.md#post_import_execution) | **POST** /1.0/api/import/execution | 
*ImportApi* | [**post_import_execution_multipart**](docs/ImportApi.md#post_import_execution_multipart) | **POST** /1.0/api/import/execution/multipart | 
*PreConditionsApi* | [**call_10_api_precondition_pre_condition_key_test_get**](docs/PreConditionsApi.md#call_10_api_precondition_pre_condition_key_test_get) | **GET** /1.0/api/precondition/{preConditionKey}/test | 
*PreConditionsApi* | [**call_10_api_precondition_pre_condition_key_test_post**](docs/PreConditionsApi.md#call_10_api_precondition_pre_condition_key_test_post) | **POST** /1.0/api/precondition/{preConditionKey}/test | 
*PreConditionsApi* | [**call_10_api_precondition_pre_condition_key_test_test_key_delete**](docs/PreConditionsApi.md#call_10_api_precondition_pre_condition_key_test_test_key_delete) | **DELETE** /1.0/api/precondition/{preConditionKey}/test/{testKey} | 
*ProjectApi* | [**call_10_api_project_id_settings_customfields_testruns_get**](docs/ProjectApi.md#call_10_api_project_id_settings_customfields_testruns_get) | **GET** /1.0/api/project/{id}/settings/customfields/testruns | 
*ProjectApi* | [**call_10_api_project_id_settings_customfields_teststeps_get**](docs/ProjectApi.md#call_10_api_project_id_settings_customfields_teststeps_get) | **GET** /1.0/api/project/{id}/settings/customfields/teststeps | 
*RequirementStatusApi* | [**call_10_api_requirementstatus_reset_put**](docs/RequirementStatusApi.md#call_10_api_requirementstatus_reset_put) | **PUT** /1.0/api/requirementstatus/reset | 
*TestExecutionTestsApi* | [**call_10_api_testexec_test_exec_key_test_get**](docs/TestExecutionTestsApi.md#call_10_api_testexec_test_exec_key_test_get) | **GET** /1.0/api/testexec/{testExecKey}/test | 
*TestExecutionTestsApi* | [**call_10_api_testexec_test_exec_key_test_post**](docs/TestExecutionTestsApi.md#call_10_api_testexec_test_exec_key_test_post) | **POST** /1.0/api/testexec/{testExecKey}/test | 
*TestExecutionTestsApi* | [**call_10_api_testexec_test_exec_key_test_test_key_delete**](docs/TestExecutionTestsApi.md#call_10_api_testexec_test_exec_key_test_test_key_delete) | **DELETE** /1.0/api/testexec/{testExecKey}/test/{testKey} | 
*TestPlanTestExecutionsApi* | [**call_10_api_testplan_test_plan_key_testexecution_get**](docs/TestPlanTestExecutionsApi.md#call_10_api_testplan_test_plan_key_testexecution_get) | **GET** /1.0/api/testplan/{testPlanKey}/testexecution | 
*TestPlanTestExecutionsApi* | [**call_10_api_testplan_test_plan_key_testexecution_post**](docs/TestPlanTestExecutionsApi.md#call_10_api_testplan_test_plan_key_testexecution_post) | **POST** /1.0/api/testplan/{testPlanKey}/testexecution | 
*TestPlanTestExecutionsApi* | [**call_10_api_testplan_test_plan_key_testexecution_test_exec_key_delete**](docs/TestPlanTestExecutionsApi.md#call_10_api_testplan_test_plan_key_testexecution_test_exec_key_delete) | **DELETE** /1.0/api/testplan/{testPlanKey}/testexecution/{testExecKey} | 
*TestPlanTestsApi* | [**call_10_api_testplan_test_plan_key_test_get**](docs/TestPlanTestsApi.md#call_10_api_testplan_test_plan_key_test_get) | **GET** /1.0/api/testplan/{testPlanKey}/test | 
*TestPlanTestsApi* | [**call_10_api_testplan_test_plan_key_test_post**](docs/TestPlanTestsApi.md#call_10_api_testplan_test_plan_key_test_post) | **POST** /1.0/api/testplan/{testPlanKey}/test | 
*TestPlanTestsApi* | [**call_10_api_testplan_test_plan_key_test_test_key_delete**](docs/TestPlanTestsApi.md#call_10_api_testplan_test_plan_key_test_test_key_delete) | **DELETE** /1.0/api/testplan/{testPlanKey}/test/{testKey} | 
*TestRepositoryApi* | [**call_10_api_testrepository_project_key_folders_folder_id_delete**](docs/TestRepositoryApi.md#call_10_api_testrepository_project_key_folders_folder_id_delete) | **DELETE** /1.0/api/testrepository/{projectKey}/folders/{folderId} | 
*TestRepositoryApi* | [**call_10_api_testrepository_project_key_folders_folder_id_get**](docs/TestRepositoryApi.md#call_10_api_testrepository_project_key_folders_folder_id_get) | **GET** /1.0/api/testrepository/{projectKey}/folders/{folderId} | 
*TestRepositoryApi* | [**call_10_api_testrepository_project_key_folders_folder_id_post**](docs/TestRepositoryApi.md#call_10_api_testrepository_project_key_folders_folder_id_post) | **POST** /1.0/api/testrepository/{projectKey}/folders/{folderId} | 
*TestRepositoryApi* | [**call_10_api_testrepository_project_key_folders_folder_id_put**](docs/TestRepositoryApi.md#call_10_api_testrepository_project_key_folders_folder_id_put) | **PUT** /1.0/api/testrepository/{projectKey}/folders/{folderId} | 
*TestRepositoryApi* | [**call_10_api_testrepository_project_key_folders_folder_id_tests_get**](docs/TestRepositoryApi.md#call_10_api_testrepository_project_key_folders_folder_id_tests_get) | **GET** /1.0/api/testrepository/{projectKey}/folders/{folderId}/tests | 
*TestRepositoryApi* | [**call_10_api_testrepository_project_key_folders_folder_id_tests_put**](docs/TestRepositoryApi.md#call_10_api_testrepository_project_key_folders_folder_id_tests_put) | **PUT** /1.0/api/testrepository/{projectKey}/folders/{folderId}/tests | 
*TestRepositoryApi* | [**call_10_api_testrepository_project_key_folders_get**](docs/TestRepositoryApi.md#call_10_api_testrepository_project_key_folders_get) | **GET** /1.0/api/testrepository/{projectKey}/folders | 
*TestRunApi* | [**call_10_api_testrun_get**](docs/TestRunApi.md#call_10_api_testrun_get) | **GET** /1.0/api/testrun | 
*TestRunApi* | [**call_10_api_testrun_id_customfield_custom_field_id_get**](docs/TestRunApi.md#call_10_api_testrun_id_customfield_custom_field_id_get) | **GET** /1.0/api/testrun/{id}/customfield/{customFieldId} | 
*TestRunApi* | [**call_10_api_testrun_id_customfield_custom_field_id_put**](docs/TestRunApi.md#call_10_api_testrun_id_customfield_custom_field_id_put) | **PUT** /1.0/api/testrun/{id}/customfield/{customFieldId} | 
*TestRunApi* | [**call_10_api_testrun_id_get**](docs/TestRunApi.md#call_10_api_testrun_id_get) | **GET** /1.0/api/testrun/{id} | 
*TestRunApi* | [**call_10_api_testrun_id_iteration_iteration_id_get**](docs/TestRunApi.md#call_10_api_testrun_id_iteration_iteration_id_get) | **GET** /1.0/api/testrun/{id}/iteration/{iterationId} | 
*TestRunApi* | [**call_10_api_testrun_id_iteration_iteration_id_put**](docs/TestRunApi.md#call_10_api_testrun_id_iteration_iteration_id_put) | **PUT** /1.0/api/testrun/{id}/iteration/{iterationId} | 
*TestRunApi* | [**call_10_api_testrun_id_iteration_iteration_id_step_get**](docs/TestRunApi.md#call_10_api_testrun_id_iteration_iteration_id_step_get) | **GET** /1.0/api/testrun/{id}/iteration/{iterationId}/step | 
*TestRunApi* | [**call_10_api_testrun_id_iteration_iteration_id_step_step_result_id_attachment_attachment_id_delete**](docs/TestRunApi.md#call_10_api_testrun_id_iteration_iteration_id_step_step_result_id_attachment_attachment_id_delete) | **DELETE** /1.0/api/testrun/{id}/iteration/{iterationId}/step/{stepResultId}/attachment/{attachmentId} | 
*TestRunApi* | [**call_10_api_testrun_id_iteration_iteration_id_step_step_result_id_attachment_delete**](docs/TestRunApi.md#call_10_api_testrun_id_iteration_iteration_id_step_step_result_id_attachment_delete) | **DELETE** /1.0/api/testrun/{id}/iteration/{iterationId}/step/{stepResultId}/attachment | 
*TestRunApi* | [**call_10_api_testrun_id_iteration_iteration_id_step_step_result_id_attachment_get**](docs/TestRunApi.md#call_10_api_testrun_id_iteration_iteration_id_step_step_result_id_attachment_get) | **GET** /1.0/api/testrun/{id}/iteration/{iterationId}/step/{stepResultId}/attachment | 
*TestRunApi* | [**call_10_api_testrun_id_iteration_iteration_id_step_step_result_id_attachment_post**](docs/TestRunApi.md#call_10_api_testrun_id_iteration_iteration_id_step_step_result_id_attachment_post) | **POST** /1.0/api/testrun/{id}/iteration/{iterationId}/step/{stepResultId}/attachment | 
*TestRunApi* | [**call_10_api_testrun_id_iteration_iteration_id_step_step_result_id_get**](docs/TestRunApi.md#call_10_api_testrun_id_iteration_iteration_id_step_step_result_id_get) | **GET** /1.0/api/testrun/{id}/iteration/{iterationId}/step/{stepResultId} | 
*TestRunApi* | [**call_10_api_testrun_id_iteration_iteration_id_step_step_result_id_put**](docs/TestRunApi.md#call_10_api_testrun_id_iteration_iteration_id_step_step_result_id_put) | **PUT** /1.0/api/testrun/{id}/iteration/{iterationId}/step/{stepResultId} | 
*TestRunApi* | [**call_10_api_testrun_id_iteration_iteration_id_step_step_result_id_status_get**](docs/TestRunApi.md#call_10_api_testrun_id_iteration_iteration_id_step_step_result_id_status_get) | **GET** /1.0/api/testrun/{id}/iteration/{iterationId}/step/{stepResultId}/status | 
*TestRunApi* | [**call_10_api_testrun_id_iteration_iteration_id_step_step_result_id_status_put**](docs/TestRunApi.md#call_10_api_testrun_id_iteration_iteration_id_step_step_result_id_status_put) | **PUT** /1.0/api/testrun/{id}/iteration/{iterationId}/step/{stepResultId}/status | 
*TestRunApi* | [**call_10_api_testrun_id_put**](docs/TestRunApi.md#call_10_api_testrun_id_put) | **PUT** /1.0/api/testrun/{id} | 
*TestRunApi* | [**get_testruns**](docs/TestRunApi.md#get_testruns) | **GET** /1.0/api/testruns | 
*TestRunStatusApi* | [**call_10_api_testrunstatus_reset_put**](docs/TestRunStatusApi.md#call_10_api_testrunstatus_reset_put) | **PUT** /1.0/api/testrunstatus/reset | 
*TestSetsApi* | [**call_10_api_testset_test_set_key_test_get**](docs/TestSetsApi.md#call_10_api_testset_test_set_key_test_get) | **GET** /1.0/api/testset/{testSetKey}/test | 
*TestSetsApi* | [**call_10_api_testset_test_set_key_test_post**](docs/TestSetsApi.md#call_10_api_testset_test_set_key_test_post) | **POST** /1.0/api/testset/{testSetKey}/test | 
*TestSetsApi* | [**call_10_api_testset_test_set_key_test_test_key_delete**](docs/TestSetsApi.md#call_10_api_testset_test_set_key_test_test_key_delete) | **DELETE** /1.0/api/testset/{testSetKey}/test/{testKey} | 
*TestStepApi* | [**call_10_api_test_test_key_step_put**](docs/TestStepApi.md#call_10_api_test_test_key_step_put) | **PUT** /1.0/api/test/{testKey}/step | 
*TestStepApi* | [**call_10_api_test_test_key_steps_get**](docs/TestStepApi.md#call_10_api_test_test_key_steps_get) | **GET** /1.0/api/test/{testKey}/steps | 
*TestStepApi* | [**call_10_api_test_test_key_steps_step_id_attachment_attachment_id_delete**](docs/TestStepApi.md#call_10_api_test_test_key_steps_step_id_attachment_attachment_id_delete) | **DELETE** /1.0/api/test/{testKey}/steps/{stepId}/attachment/{attachmentId} | 
*TestStepApi* | [**call_10_api_test_test_key_steps_step_id_attachments_get**](docs/TestStepApi.md#call_10_api_test_test_key_steps_step_id_attachments_get) | **GET** /1.0/api/test/{testKey}/steps/{stepId}/attachments | 
*TestStepApi* | [**call_10_api_test_test_key_steps_step_id_delete**](docs/TestStepApi.md#call_10_api_test_test_key_steps_step_id_delete) | **DELETE** /1.0/api/test/{testKey}/steps/{stepId} | 
*TestStepApi* | [**call_10_api_test_test_key_steps_step_id_get**](docs/TestStepApi.md#call_10_api_test_test_key_steps_step_id_get) | **GET** /1.0/api/test/{testKey}/steps/{stepId} | 
*TestStepApi* | [**call_10_api_test_test_key_steps_step_id_put**](docs/TestStepApi.md#call_10_api_test_test_key_steps_step_id_put) | **PUT** /1.0/api/test/{testKey}/steps/{stepId} | 
*TestsApi* | [**call_10_api_settings_teststatuses_get**](docs/TestsApi.md#call_10_api_settings_teststatuses_get) | **GET** /1.0/api/settings/teststatuses | 
*TestsApi* | [**call_10_api_test_get**](docs/TestsApi.md#call_10_api_test_get) | **GET** /1.0/api/test | 
*TestsApi* | [**call_10_api_test_key_preconditions_get**](docs/TestsApi.md#call_10_api_test_key_preconditions_get) | **GET** /1.0/api/test/{key}/preconditions | 
*TestsApi* | [**call_10_api_test_key_testexecutions_get**](docs/TestsApi.md#call_10_api_test_key_testexecutions_get) | **GET** /1.0/api/test/{key}/testexecutions | 
*TestsApi* | [**call_10_api_test_key_testplans_get**](docs/TestsApi.md#call_10_api_test_key_testplans_get) | **GET** /1.0/api/test/{key}/testplans | 
*TestsApi* | [**call_10_api_test_key_testruns_get**](docs/TestsApi.md#call_10_api_test_key_testruns_get) | **GET** /1.0/api/test/{key}/testruns | 
*TestsApi* | [**call_10_api_test_key_testsets_get**](docs/TestsApi.md#call_10_api_test_key_testsets_get) | **GET** /1.0/api/test/{key}/testsets | 


## Documentation For Models

 - [CalledStep](docs/CalledStep.md)
 - [CreateStep](docs/CreateStep.md)
 - [CreateStepRequestBody](docs/CreateStepRequestBody.md)
 - [CreateStepResponse](docs/CreateStepResponse.md)
 - [CreateStepResponseStep](docs/CreateStepResponseStep.md)
 - [CustomFieldMetaInformation](docs/CustomFieldMetaInformation.md)
 - [DataField](docs/DataField.md)
 - [DatasetParameter](docs/DatasetParameter.md)
 - [Defects](docs/Defects.md)
 - [Error](docs/Error.md)
 - [FieldValue](docs/FieldValue.md)
 - [File](docs/File.md)
 - [FileResponse](docs/FileResponse.md)
 - [FolderRestBean](docs/FolderRestBean.md)
 - [GetTestruns200ResponseInner](docs/GetTestruns200ResponseInner.md)
 - [GetTestruns200ResponseInnerEvidencesInner](docs/GetTestruns200ResponseInnerEvidencesInner.md)
 - [GetTestruns200ResponseInnerStepsInner](docs/GetTestruns200ResponseInnerStepsInner.md)
 - [IterationStepInformation](docs/IterationStepInformation.md)
 - [Model10ApiTestrepositoryProjectKeyFoldersFolderIdGet200Response](docs/Model10ApiTestrepositoryProjectKeyFoldersFolderIdGet200Response.md)
 - [Model10ApiTestrunIdCustomfieldCustomFieldIdPutRequest](docs/Model10ApiTestrunIdCustomfieldCustomFieldIdPutRequest.md)
 - [Model10ApiTestrunIdIterationIterationIdStepStepResultIdStatusGet200Response](docs/Model10ApiTestrunIdIterationIterationIdStepStepResultIdStatusGet200Response.md)
 - [OptionCustomFieldMetaInformation](docs/OptionCustomFieldMetaInformation.md)
 - [OptionField](docs/OptionField.md)
 - [OptionValue](docs/OptionValue.md)
 - [ProjectTestRunCFMetaInformationInner](docs/ProjectTestRunCFMetaInformationInner.md)
 - [ProjectTestStepCFMetaInformationInner](docs/ProjectTestStepCFMetaInformationInner.md)
 - [RestApiSuccessResponse](docs/RestApiSuccessResponse.md)
 - [RestApiSuccessResponseTestExecIssue](docs/RestApiSuccessResponseTestExecIssue.md)
 - [RestApiSuccessResponseTestIssues](docs/RestApiSuccessResponseTestIssues.md)
 - [RestApiSuccessResponseTestIssuesErrorInner](docs/RestApiSuccessResponseTestIssuesErrorInner.md)
 - [RestApiSuccessResponseTestIssuesSuccessInner](docs/RestApiSuccessResponseTestIssuesSuccessInner.md)
 - [RestApiSuccessResponseTestRunWarningsInner](docs/RestApiSuccessResponseTestRunWarningsInner.md)
 - [Step](docs/Step.md)
 - [StepCustomFieldMetaInformation](docs/StepCustomFieldMetaInformation.md)
 - [StepFieldsValue](docs/StepFieldsValue.md)
 - [StepOptionCustomFieldMetaInformation](docs/StepOptionCustomFieldMetaInformation.md)
 - [StepResponse](docs/StepResponse.md)
 - [StepResult](docs/StepResult.md)
 - [StepResultActualResult](docs/StepResultActualResult.md)
 - [StepResultComment](docs/StepResultComment.md)
 - [StepResultsResponse](docs/StepResultsResponse.md)
 - [TestExampleStepBean](docs/TestExampleStepBean.md)
 - [TestResponseInner](docs/TestResponseInner.md)
 - [TestResponseInnerDefinition](docs/TestResponseInnerDefinition.md)
 - [TestResponseInnerDefinitionOneOf](docs/TestResponseInnerDefinitionOneOf.md)
 - [TestResponseInnerDefinitionOneOfStepsInner](docs/TestResponseInnerDefinitionOneOfStepsInner.md)
 - [TestResponseInnerDefinitionOneOfStepsInnerStep](docs/TestResponseInnerDefinitionOneOfStepsInnerStep.md)
 - [TestResponseInnerPreconditionInner](docs/TestResponseInnerPreconditionInner.md)
 - [TestRunCustomFieldMulti](docs/TestRunCustomFieldMulti.md)
 - [TestRunCustomFieldResponse](docs/TestRunCustomFieldResponse.md)
 - [TestRunCustomFieldSingle](docs/TestRunCustomFieldSingle.md)
 - [TestRunExample](docs/TestRunExample.md)
 - [TestRunIterationInformation](docs/TestRunIterationInformation.md)
 - [TestRunIterationStatusInformation](docs/TestRunIterationStatusInformation.md)
 - [TestRunResponse](docs/TestRunResponse.md)
 - [TestRunResponseCustomFieldsInner](docs/TestRunResponseCustomFieldsInner.md)
 - [TestStepResultEvidenceInput](docs/TestStepResultEvidenceInput.md)
 - [TestStepsResponse](docs/TestStepsResponse.md)
 - [TestStepsResponseStepsInner](docs/TestStepsResponseStepsInner.md)
 - [UpdateIteration](docs/UpdateIteration.md)
 - [UpdateIterationResponse](docs/UpdateIterationResponse.md)
 - [UpdateIterationStatus](docs/UpdateIterationStatus.md)
 - [UpdateStep](docs/UpdateStep.md)
 - [UpdateStepAttachments](docs/UpdateStepAttachments.md)
 - [UpdateStepRequestBody](docs/UpdateStepRequestBody.md)
 - [UpdateStepResult](docs/UpdateStepResult.md)
 - [UpdateStepResultDefects](docs/UpdateStepResultDefects.md)
 - [UpdateStepResultEvidences](docs/UpdateStepResultEvidences.md)
 - [UpdateTRCustomFieldValueMulti](docs/UpdateTRCustomFieldValueMulti.md)
 - [UpdateTRCustomFieldValueSingle](docs/UpdateTRCustomFieldValueSingle.md)
 - [UpdateTestRun](docs/UpdateTestRun.md)
 - [UpdateTestRunCustomFieldMulti](docs/UpdateTestRunCustomFieldMulti.md)
 - [UpdateTestRunCustomFieldSingle](docs/UpdateTestRunCustomFieldSingle.md)
 - [UpdateTestRunCustomFieldsInner](docs/UpdateTestRunCustomFieldsInner.md)
 - [UpdateTestRunEvidences](docs/UpdateTestRunEvidences.md)
 - [UpdateTestRunExamples](docs/UpdateTestRunExamples.md)
 - [UpdateTestRunResponse](docs/UpdateTestRunResponse.md)
 - [Version](docs/Version.md)
 - [WikiField](docs/WikiField.md)
 - [WikiValue](docs/WikiValue.md)
 - [XrayJsonImportExecution](docs/XrayJsonImportExecution.md)
 - [XrayJsonImportExecutionInfo](docs/XrayJsonImportExecutionInfo.md)
 - [XrayJsonImportExecutionTestsInner](docs/XrayJsonImportExecutionTestsInner.md)
 - [XrayJsonImportExecutionTestsInnerEvidencesInner](docs/XrayJsonImportExecutionTestsInnerEvidencesInner.md)
 - [XrayJsonImportExecutionTestsInnerResultsInner](docs/XrayJsonImportExecutionTestsInnerResultsInner.md)
 - [XrayJsonImportExecutionTestsInnerStepsInner](docs/XrayJsonImportExecutionTestsInnerStepsInner.md)
 - [XrayJsonImportExecutionTestsInnerTestInfo](docs/XrayJsonImportExecutionTestsInnerTestInfo.md)
 - [XrayLicenseStatus](docs/XrayLicenseStatus.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="BasicAuth"></a>
### BasicAuth

- **Type**: HTTP basic authentication

<a id="bearerAuth"></a>
### bearerAuth

- **Type**: Bearer authentication


## Author




